==> apache-uniffle-0.6.1-incubating-src.tar.gz: apache-uniffle-0.6.1-incubating-src/common/src/main/java/org/apache/uniffle/common/ShufflePartitionedData.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.uniffle.common;

import java.util.Arrays;

public class ShufflePartitionedData {

  private int partitionId;
  private ShufflePartitionedBlock[] blockList;

  public ShufflePartitionedData(int partitionId, ShufflePartitionedBlock[] blockList) {
    this.partitionId = partitionId;
    this.blockList = blockList;
  }

  @Override
  public String toString() {
    return "ShufflePartitionedData{partitionId=" + partitionId + ", blockList=" + Arrays.toString(blockList) + '}';
  }

  public int getPartitionId() {
    return partitionId;
  }

  public void setPartitionId(int partitionId) {
    this.partitionId = partitionId;
  }

  public ShufflePartitionedBlock[] getBlockList() {
    if (blockList == null) {
      return new ShufflePartitionedBlock[]{};
    }
    return blockList;
  }

}

==> apache-uniffle-0.7.1-incubating-src.tar.gz: apache-uniffle-0.7.1-incubating-src/common/src/main/java/org/apache/uniffle/common/ShufflePartitionedData.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.uniffle.common;

import java.util.Arrays;

public class ShufflePartitionedData {

  private int partitionId;
  private ShufflePartitionedBlock[] blockList;

  public ShufflePartitionedData(int partitionId, ShufflePartitionedBlock[] blockList) {
    this.partitionId = partitionId;
    this.blockList = blockList;
  }

  @Override
  public String toString() {
    return "ShufflePartitionedData{partitionId=" + partitionId + ", blockList=" + Arrays.toString(blockList) + '}';
  }

  public int getPartitionId() {
    return partitionId;
  }

  public void setPartitionId(int partitionId) {
    this.partitionId = partitionId;
  }

  public ShufflePartitionedBlock[] getBlockList() {
    if (blockList == null) {
      return new ShufflePartitionedBlock[]{};
    }
    return blockList;
  }

  public long getTotalBlockSize() {
    if (blockList == null) {
      return 0L;
    }
    long size = 0;
    for (ShufflePartitionedBlock block : blockList) {
      size += block.getSize();
    }
    return size;
  }

}
